@@ -108,7 +108,9 @@
 #'  g <- 1 + rowSums(x[, 2:n, drop = FALSE]) * 9/(n - 1)
 #'  return(cbind(x[, 1], g * (1 - sqrt(x[, 1]/g))))
 #' }
-#' \donttest{
+#'
+#' #Not run
+#' \dontrun{
 #' result <- nsga3(type = "real-valued",
 #'                 fitness = zdt1,
 #'                 lower = c(0,0),
@@ -135,7 +137,9 @@
 #'     f <- tmp * tmp2 * 0.5 * (1 + g)
 #'     return(f)
 #' }
-#' \donttest{
+#'
+#' #Not Run
+#' \dontrun{
 #' result <- nsga3(type = "real-valued",
 #'                 fitness = dtlz1,
 #'                 lower = c(0,0,0),
@@ -166,7 +170,7 @@ nsga3 <- function(type = c("binary", "real-valued", "permutation"),
     names = NULL,
     suggestions = NULL,
     monitor = if (interactive()) nsgaMonitor else FALSE,
-    summary = TRUE,
+    summary = FALSE,
     seed = NULL)
 {
     call <- match.call()
@@ -531,7 +535,7 @@ nsga3 <- function(type = c("binary", "real-valued", "permutation"),
       rm(out)
 
       if (summary == TRUE) {
-        fitnessSummary[[iter]] <- nsgaiiiSummary(object)
+        fitnessSummary[[iter]] <- Summary(object)
         object@summary <- fitnessSummary
       } else {
         object@summary <- list()
